==> cups_2.3.1.orig.tar.gz: cups-2.3.1/CREDITS.md <==
CREDITS - 2019-08-21
====================

Few projects are completed by one person, and CUPS is no exception.  We'd like
to thank the following individuals for their contributions:

    Niklas 'Nille' Åkerström       - Swedish localization.
    Nathaniel Barbour              - Lots of testing and feedback.
    N. Becker                      - setsid().
    Philippe Combes                - French localization and buttons script.
    Jean-Eric Cuendet              - GhostScript filters for CUPS.
    Van Dang                       - HTTP and IPP policeman.
    L. Peter Deutsch               - MD5 code.
    Dr. ZP Han                     - setgid()/setuid().
    Guy Harris                     - *BSD shared libraries and lots of other
                                     fixes.
    Bjoern Jacke                   - I18N stuff.
    Wang Jian                      - CUPS RPM corrections.
    Roderick Johnstone             - Beta tester of the millenium.
    Till Kamppeter                 - Bug fixes, beta testing, evangelism.
    Tomohiro Kato                  - Japanese localization.
    Kiko                           - Bug fixes.
    Sergey V. Kovalyov             - ESP Print Pro and CUPS beta tester.
    Marek Laane                    - Estonian translation.
    Iñaki Larrañaga                - Basque localization.
    Mark Lawrence                  - Microsoft interoperability testing.
    Jeff Licquia                   - Bug fixes, beta testing, evangelism.
    Jason McMullan                 - Original CUPS RPM distributions.
    Àngel Mompó                    - Catalan localization.
    Wes Morgan                     - *BSD fixes.
    Kenshi Muto                    - Japanese localization, patches, and
                                     testing.
    Brian Norris                   - Upstart support.
    Daniel Nylander                - Swedish localization.
    Naruiko Ogasawara              - Japanese localization.
    Giulio Orsero                  - Bug fixes and testing.
    Michal Osowiecki               - Polish localization.
    Citra Paska                    - Indonesian localization.
    Kurt Pfeifle                   - Bug fixes, beta testing, evangelism.
    Vincenzo Reale                 - Italian localization.
    Petter Reinholdtsen            - HP-UX compiler stuff.
    Juan Pablo González Riopedre   - Spanish localization.
    Giovanni Scafora               - Italian localization.
    Joachim Schwender              - German localization.
    Opher Shachar                  - Hebrew localization.
    Stuart Stevens                 - HP JetDirect IPP information.
    Andrea Suatoni                 - IRIX desktop integration and testing.
    Teppo Turliainen               - Finnish localization.
    Tim Waugh                      - Lots of patches, testing, and Linux
                                     integration.
    Yugami                         - LDAP browsing support.

If I've missed someone, please let me know by sending an email to
"msweet@apple.com".

==> cups_2.4.2.orig.tar.gz: cups-2.4.2/CREDITS.md <==
Credits
=======

Few projects are completed by one person, and CUPS is no exception.  We'd like
to thank the following individuals for their contributions:

    Niklas 'Nille' Åkerström       - Swedish localization.
    Nathaniel Barbour              - Lots of testing and feedback.
    N. Becker                      - setsid().
    Philippe Combes                - French localization and buttons script.
    Jean-Eric Cuendet              - GhostScript filters for CUPS.
    Van Dang                       - HTTP and IPP policeman.
    L. Peter Deutsch               - MD5 code.
    Dr. ZP Han                     - setgid()/setuid().
    Guy Harris                     - *BSD shared libraries and lots of other
                                     fixes.
    Bjoern Jacke                   - I18N stuff.
    Wang Jian                      - CUPS RPM corrections.
    Roderick Johnstone             - Beta tester of the millenium.
    Till Kamppeter                 - Bug fixes, beta testing, evangelism.
    Tomohiro Kato                  - Japanese localization.
    Kiko                           - Bug fixes.
    Sergey V. Kovalyov             - ESP Print Pro and CUPS beta tester.
    Marek Laane                    - Estonian translation.
    Iñaki Larrañaga                - Basque localization.
    Mark Lawrence                  - Microsoft interoperability testing.
    Jeff Licquia                   - Bug fixes, beta testing, evangelism.
    Jason McMullan                 - Original CUPS RPM distributions.
    Àngel Mompó                    - Catalan localization.
    Wes Morgan                     - *BSD fixes.
    Kenshi Muto                    - Japanese localization, patches, and
                                     testing.
    Brian Norris                   - Upstart support.
    Daniel Nylander                - Swedish localization.
    Naruiko Ogasawara              - Japanese localization.
    Giulio Orsero                  - Bug fixes and testing.
    Michal Osowiecki               - Polish localization.
    Citra Paska                    - Indonesian localization.
    Kurt Pfeifle                   - Bug fixes, beta testing, evangelism.
    Vincenzo Reale                 - Italian localization.
    Petter Reinholdtsen            - HP-UX compiler stuff.
    Juan Pablo González Riopedre   - Spanish localization.
    Giovanni Scafora               - Italian localization.
    Joachim Schwender              - German localization.
    Opher Shachar                  - Hebrew localization.
    Stuart Stevens                 - HP JetDirect IPP information.
    Andrea Suatoni                 - IRIX desktop integration and testing.
    Teppo Turliainen               - Finnish localization.
    Tim Waugh                      - Lots of patches, testing, and Linux
                                     integration.
    Yugami                         - LDAP browsing support.

If we've missed someone, please let us know by filing an issue at
<https://github.com/openprinting/cups/issues>.
